==> eiffelstudio-18.11.10.2592.tar: F_code/C5/ew224.c <==
/*
 * Code for class EW_C_COMPILE_INST
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ew224.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EW_C_COMPILE_INST}.inst_initialize */
void F743_4185 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLIU(4);
	
	RTEAA("inst_initialize", 742, Current, 1, 1, 8941);
	RTGC;
	RTHOOK(1);
	loc1 = F38_587(Current, arg1);
	RTHOOK(2);
	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R2566[Dtype(loc1)-535])(RTCW(loc1));
	if ((EIF_BOOLEAN) (ti4_1 > ((EIF_INTEGER_32) 1L))) {
		RTHOOK(3);
		*(EIF_BOOLEAN *)(Current+ _CHROFF_7_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
		RTHOOK(4);
		tr1 = RTMS32_EX_H("m\000\000\000u\000\000\000s\000\000\000t\000\000\000 \000\000\000s\000\000\000u\000\000\000p\000\000\000p\000\000\000l\000\000\000y\000\000\000 \000\000\0000\000\000\000 \000\000\000o\000\000\000r\000\000\000 \000\000\0001\000\000\000 \000\000\000a\000\000\000r\000\000\000g\000\000\000u\000\000\000m\000\000\000e\000\000\000n\000\000\000t\000\000\000",27,1435733876);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	} else {
		RTHOOK(5);
		ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R2566[Dtype(loc1)-535])(RTCW(loc1));
		if ((EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 1L))) {
			RTHOOK(6);
			ti4_1 = ((EIF_INTEGER_32) 1L);
			tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R2586[Dtype(loc1)-562])(RTCW(loc1), (EIF_REFERENCE) &ti4_1);
			RTAR(Current, tr1);
			*(EIF_REFERENCE *)(Current + _REFACS_6_) = (EIF_REFERENCE) tr1;
			RTHOOK(7);
			*(EIF_BOOLEAN *)(Current+ _CHROFF_7_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
		} else {
			RTHOOK(8);
			*(EIF_BOOLEAN *)(Current+ _CHROFF_7_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
		}
	}
	RTHOOK(9);
	RTLE;
	RTEE;
}

/* {EW_C_COMPILE_INST}.execute */
void F743_4186 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 loc5 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	RTLD;
	
	RTLI(10);
	RTLR(0,loc3);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLR(4,loc4);
	RTLR(5,loc1);
	RTLR(6,loc2);
	RTLR(7,tr2);
	RTLR(8,tr3);
	RTLR(9,loc6);
	RTLIU(10);
	
	RTEAA("execute", 742, Current, 6, 1, 8942);
	RTGC;
	RTHOOK(1);
	loc3 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
	tr1 = RTOUCR(52,F730_4123,(Current));
	loc3 = F643_3642(RTCW(loc3), tr1);
	RTHOOK(2);
	loc4 = F40_616(Current, loc3);
	RTHOOK(3);
	if ((EIF_BOOLEAN)(loc4 == NULL)) {
		RTHOOK(4);
		F908_6214(RTCW(arg1));
		RTHOOK(5);
		loc1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R3353[Dtype(Current)-743])(Current);
		loc1 = F643_3642(RTCW(loc1), tr1);
		RTHOOK(6);
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
		loc5 = *(EIF_INTEGER_32 *)(RTCW(tr1)+ _LNGOFF_3_0_0_1_);
		RTHOOK(7);
		loc2 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
		RTHOOK(8);
		if ((EIF_BOOLEAN) !(EIF_BOOLEAN)(loc2 != NULL)) {
			RTHOOK(9);
			loc2 = F908_6193(RTCW(arg1));
		}
		RTHOOK(10);
		tr1 = RTOUCR(17,F731_4126,(Current));
		tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
		tr3 = RTOUCR(21,F730_4119,(Current));
		tr2 = F643_3642(RTCW(tr2), tr3);
		loc2 = F203_2287(RTCW(tr1), tr2, loc2);
		RTHOOK(11);
		tr1 = RTLNS(eif_new_type(923, 0x00).id, 923, _OBJSIZ_6_3_0_0_0_0_0_0_);
		tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
		tr2 = *(EIF_REFERENCE *)(RTCW(tr2));
		F924_6488(RTCW(tr1), loc1, loc2, loc3, tr2, loc5);
		loc6 = (EIF_REFERENCE) tr1;
		RTHOOK(12);
		F908_6208(RTCW(arg1), loc6);
		RTHOOK(13);
		tr1 = F922_6471(RTCW(loc6));
		F908_6210(RTCW(arg1), tr1);
		RTHOOK(14);
		*(EIF_BOOLEAN *)(Current+ _CHROFF_7_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	} else {
		RTHOOK(15);
		tr1 = F892_5610(RTCW(loc4));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
		RTHOOK(16);
		*(EIF_BOOLEAN *)(Current+ _CHROFF_7_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	}
	RTHOOK(17);
	RTLE;
	RTEE;
}

/* {EW_C_COMPILE_INST}.init_ok */
EIF_BOOLEAN F743_4187 (EIF_REFERENCE Current)
{
	return *(EIF_BOOLEAN *)(Current+ _CHROFF_7_1_);
}


/* {EW_C_COMPILE_INST}.execute_ok */
EIF_BOOLEAN F743_4188 (EIF_REFERENCE Current)
{
	return *(EIF_BOOLEAN *)(Current+ _CHROFF_7_0_);
}


/* {EW_C_COMPILE_INST}.output_file_name */
EIF_REFERENCE F743_4189 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_6_);
}


void EIF_Minit224 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C5/ew224.c <==
/*
 * Code for class EW_C_COMPILE_INST
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ew224.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EW_C_COMPILE_INST}.inst_initialize */
void F743_4192 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLIU(4);
	
	RTEAA("inst_initialize", 742, Current, 1, 1, 8948);
	RTGC;
	RTHOOK(1);
	loc1 = F38_587(Current, arg1);
	RTHOOK(2);
	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R2568[Dtype(RTCW(loc1))-536])(loc1);
	if ((EIF_BOOLEAN) (ti4_1 > ((EIF_INTEGER_32) 1L))) {
		RTHOOK(3);
		*(EIF_BOOLEAN *)(Current+ _CHROFF_7_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
		RTHOOK(4);
		tr1 = RTMS32_EX_H("m\000\000\000u\000\000\000s\000\000\000t\000\000\000 \000\000\000s\000\000\000u\000\000\000p\000\000\000p\000\000\000l\000\000\000y\000\000\000 \000\000\0000\000\000\000 \000\000\000o\000\000\000r\000\000\000 \000\000\0001\000\000\000 \000\000\000a\000\000\000r\000\000\000g\000\000\000u\000\000\000m\000\000\000e\000\000\000n\000\000\000t\000\000\000",27,1435733876);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	} else {
		RTHOOK(5);
		ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R2568[Dtype(RTCW(loc1))-536])(loc1);
		if ((EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 1L))) {
			RTHOOK(6);
			ti4_1 = ((EIF_INTEGER_32) 1L);
			tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R2588[Dtype(RTCW(loc1))-563])(loc1, (EIF_REFERENCE) &ti4_1);
			RTAR(Current, tr1);
			*(EIF_REFERENCE *)(Current + _REFACS_6_) = (EIF_REFERENCE) tr1;
			RTHOOK(7);
			*(EIF_BOOLEAN *)(Current+ _CHROFF_7_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
		} else {
			RTHOOK(8);
			*(EIF_BOOLEAN *)(Current+ _CHROFF_7_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
		}
	}
	RTHOOK(9);
	RTLE;
	RTEE;
}

/* {EW_C_COMPILE_INST}.execute */
void F743_4193 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 loc5 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	RTLD;
	
	RTLI(10);
	RTLR(0,loc3);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLR(4,loc4);
	RTLR(5,loc1);
	RTLR(6,loc2);
	RTLR(7,tr2);
	RTLR(8,tr3);
	RTLR(9,loc6);
	RTLIU(10);
	
	RTEAA("execute", 742, Current, 6, 1, 8949);
	RTGC;
	RTHOOK(1);
	loc3 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
	tr1 = RTOUCR(52,F730_4130, (Current));
	loc3 = F643_3649(RTCW(loc3), tr1);
	RTHOOK(2);
	loc4 = F40_616(Current, loc3);
	RTHOOK(3);
	if ((EIF_BOOLEAN)(loc4 == NULL)) {
		RTHOOK(4);
		F908_6235(RTCW(arg1));
		RTHOOK(5);
		loc1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R3360[Dtype(Current)-743])(Current);
		loc1 = F643_3649(RTCW(loc1), tr1);
		RTHOOK(6);
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
		loc5 = *(EIF_INTEGER_32 *)(RTCW(tr1)+ _LNGOFF_3_0_0_1_);
		RTHOOK(7);
		loc2 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
		RTHOOK(8);
		if ((EIF_BOOLEAN) !(EIF_BOOLEAN)(loc2 != NULL)) {
			RTHOOK(9);
			loc2 = F908_6214(RTCW(arg1));
		}
		RTHOOK(10);
		tr1 = RTOUCR(17,F731_4133, (Current));
		tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
		tr3 = RTOUCR(21,F730_4126, (Current));
		tr2 = F643_3649(RTCW(tr2), tr3);
		tr1 = F203_2289(RTCW(tr1), tr2, loc2);
		loc2 = (EIF_REFERENCE) tr1;
		RTHOOK(11);
		loc6 = RTLNS(eif_new_type(923, 0x00).id, 923, _OBJSIZ_6_3_0_0_0_0_0_0_);
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
		tr1 = *(EIF_REFERENCE *)(RTCW(tr1));
		F924_6509(RTCW(loc6), loc1, loc2, loc3, tr1, loc5);
		RTHOOK(12);
		F908_6229(RTCW(arg1), loc6);
		RTHOOK(13);
		tr1 = F922_6492(RTCW(loc6));
		F908_6231(RTCW(arg1), tr1);
		RTHOOK(14);
		*(EIF_BOOLEAN *)(Current+ _CHROFF_7_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	} else {
		RTHOOK(15);
		tr1 = F892_5631(RTCW(loc4));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
		RTHOOK(16);
		*(EIF_BOOLEAN *)(Current+ _CHROFF_7_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	}
	RTHOOK(17);
	RTLE;
	RTEE;
}

/* {EW_C_COMPILE_INST}.init_ok */
EIF_BOOLEAN F743_4194 (EIF_REFERENCE Current)
{
	return *(EIF_BOOLEAN *)(Current+ _CHROFF_7_1_);
}


/* {EW_C_COMPILE_INST}.execute_ok */
EIF_BOOLEAN F743_4195 (EIF_REFERENCE Current)
{
	return *(EIF_BOOLEAN *)(Current+ _CHROFF_7_0_);
}


void EIF_Minit224 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
